var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/development/src/index.js
var src_exports = {};
__export(src_exports, {
  DAITAN_LOG_LEVELS: () => DAITAN_LOG_LEVELS,
  DaitanRootLogger: () => DaitanRootLogger,
  checkEnv: () => checkEnv,
  daitanDevGoogleOAuthClient: () => googleAuth_default,
  devMultitestExample: () => devMultitestExample,
  devSimpleLog: () => devSimpleLog,
  getAllHardwareInfo: () => getAllHardwareInfo,
  getAudioDevicesInfo: () => getAudioDevicesInfo,
  getCPUInfo: () => getCPUInfo,
  getEnvVariable: () => getEnvVariable,
  getGoogleAuthClient: () => getGoogleAuthClient,
  getGraphicsAndDisplayInfo: () => getGraphicsAndDisplayInfo,
  getLoadAverage: () => getLoadAverage,
  getLogger: () => getLogger,
  getMemoryInfo: () => getMemoryInfo,
  getNetworkInfo: () => getNetworkInfo,
  getOSInfo: () => getOSInfo,
  getOptionalEnvVariable: () => getOptionalEnvVariable,
  getRequiredEnvVariable: () => getRequiredEnvVariable,
  getUsbDevicesInfo: () => getUsbDevicesInfo,
  isLogLevelEnabled: () => isLogLevelEnabled,
  isTensorFlowSupported: () => isTensorFlowSupported,
  loadEnvironmentFiles: () => loadEnvironmentFiles,
  setGlobalLogLevel: () => setGlobalLogLevel
});
module.exports = __toCommonJS(src_exports);

// src/development/src/logger.js
var import_winston = __toESM(require("winston"), 1);
var import_path2 = __toESM(require("path"), 1);

// src/development/src/environment.js
var import_dotenv = __toESM(require("dotenv"), 1);
var import_path = __toESM(require("path"), 1);
var import_fs = __toESM(require("fs"), 1);
var import_os = __toESM(require("os"), 1);
var import_error = require("@daitanjs/error");
var import_chalk = __toESM(require("chalk"), 1);
var getPreLoadEnvVar = (key, defaultValue = null) => {
  const value = process.env[key];
  return value === void 0 || value === null || String(value).trim() === "" ? defaultValue : String(value).trim();
};
function loadEnvironmentFiles(options = {}) {
  const { envPath, overrideDotenv = true, debugDotenv = false } = options;
  const pathsAttemptedThisCall = /* @__PURE__ */ new Set();
  const tryLoadSinglePath = (filePathToLoad, fileDescription) => {
    if (!filePathToLoad || typeof filePathToLoad !== "string" || !filePathToLoad.trim()) {
      return;
    }
    const tildeExpandedPath = filePathToLoad.trim().replace(/^~/, import_os.default.homedir());
    const resolvedPath = import_path.default.resolve(tildeExpandedPath);
    if (pathsAttemptedThisCall.has(resolvedPath)) return;
    pathsAttemptedThisCall.add(resolvedPath);
    if (!import_fs.default.existsSync(resolvedPath)) {
      if (debugDotenv)
        console.log(
          `[DaitanEnvLoader] File not found for ${fileDescription}: "${resolvedPath}"`
        );
      return;
    }
    if (debugDotenv)
      console.log(
        `[DaitanEnvLoader] Attempting to load .env file: "${resolvedPath}" (${fileDescription})`
      );
    import_dotenv.default.config({
      path: resolvedPath,
      override: overrideDotenv,
      debug: debugDotenv
    });
  };
  const effectiveDebug = debugDotenv || getPreLoadEnvVar("DEBUG_DOTENV") === "true";
  if (effectiveDebug)
    console.log("[DaitanEnvLoader] Initiating .env file loading sequence...");
  const nodeEnv = getPreLoadEnvVar("NODE_ENV");
  const cwd = process.cwd();
  const fileLoadOrder = [
    {
      pathStr: getPreLoadEnvVar("DAITAN_GLOBAL_ENV_PATH"),
      description: "Global DaitanJS Override via DAITAN_GLOBAL_ENV_PATH"
    },
    {
      pathStr: envPath,
      description: "Explicit path from function options"
    },
    {
      pathStr: import_path.default.join(cwd, ".env"),
      description: "Local Project (.env)"
    },
    {
      pathStr: import_path.default.join(cwd, ".env.local"),
      description: "Local Project Override (.env.local)"
    },
    ...nodeEnv ? [
      {
        pathStr: import_path.default.join(cwd, `.env.${nodeEnv}`),
        description: `Local Project (.env.${nodeEnv})`
      },
      {
        pathStr: import_path.default.join(cwd, `.env.${nodeEnv}.local`),
        description: `Local Project Override (.env.${nodeEnv}.local)`
      }
    ] : []
  ];
  fileLoadOrder.forEach(({ pathStr, description }) => {
    if (pathStr) {
      tryLoadSinglePath(pathStr, description);
    }
  });
  if (effectiveDebug)
    console.log("[DaitanEnvLoader] .env file loading sequence complete.");
}
var getEnvVariable = (key, defaultValue, options = {}) => {
  const { isRequired = false, type = "string", description = "" } = options;
  if (!key || typeof key !== "string" || !key.trim()) {
    throw new import_error.DaitanInvalidInputError(
      "Environment variable key must be a non-empty string."
    );
  }
  const trimmedKey = key.trim();
  const rawValue = process.env[trimmedKey];
  const valueString = rawValue === void 0 || rawValue === null ? "" : String(rawValue).trim();
  const isMissingOrEmpty = valueString === "";
  if (isMissingOrEmpty) {
    if (isRequired) {
      const errorMsg = `Missing required environment variable: ${trimmedKey}. Description: ${description || "N/A"}`;
      if (process.env.DAITAN_ENV_VALIDATION_MODE === "strict") {
        console.error(import_chalk.default.red.bold(`
FATAL: ${errorMsg}
`));
        process.exit(1);
      }
      throw new import_error.DaitanConfigurationError(errorMsg, { key: trimmedKey });
    }
    return defaultValue;
  }
  try {
    switch (type) {
      case "number":
        const num = parseFloat(valueString);
        if (isNaN(num))
          throw new Error(`Value "${valueString}" is not a valid number.`);
        return num;
      case "boolean":
        const lowerValue = valueString.toLowerCase();
        if (["true", "1", "yes", "on"].includes(lowerValue)) return true;
        if (["false", "0", "no", "off"].includes(lowerValue)) return false;
        throw new Error(`Value "${valueString}" is not a valid boolean.`);
      case "array":
        return valueString.split(",").map((s) => s.trim()).filter(Boolean);
      default:
        return valueString;
    }
  } catch (castError) {
    const errorMsg = `Environment variable ${trimmedKey} ("${valueString}") could not be cast to type "${type}": ${castError.message}`;
    if (isRequired) {
      if (process.env.DAITAN_ENV_VALIDATION_MODE === "strict") {
        console.error(import_chalk.default.red.bold(`
FATAL: ${errorMsg}
`));
        process.exit(1);
      }
      throw new import_error.DaitanConfigurationError(errorMsg);
    }
    return defaultValue;
  }
};
var getRequiredEnvVariable = (key, type = "string", description = "") => getEnvVariable(key, void 0, { isRequired: true, type, description });
var getOptionalEnvVariable = (key, defaultValue, options = {}) => getEnvVariable(key, defaultValue, { isRequired: false, ...options });
var checkEnv = (variableName) => !!getOptionalEnvVariable(variableName);

// src/development/src/logger.js
var import_util = require("util");
var import_crypto = __toESM(require("crypto"), 1);
var DAITAN_LOG_LEVELS = {
  error: 0,
  warn: 1,
  info: 2,
  debug: 3,
  silly: 4
};
var _DaitanRootLogger = class {
  constructor() {
    this.loggers = /* @__PURE__ */ new Map();
    this.globalLogLevel = getOptionalEnvVariable("LOG_LEVEL", "info");
  }
  setGlobalLogLevel(level) {
    if (!DAITAN_LOG_LEVELS.hasOwnProperty(level)) {
      throw new Error(`Invalid log level: ${level}`);
    }
    this.globalLogLevel = level;
    for (const [name, logger] of this.loggers) {
      logger.level = level;
    }
  }
  isLogLevelEnabled(level, loggerLevel = null) {
    const targetLevel = loggerLevel || this.globalLogLevel;
    return DAITAN_LOG_LEVELS[level] <= DAITAN_LOG_LEVELS[targetLevel];
  }
  createLogger(category) {
    const logLevel = getOptionalEnvVariable("LOG_LEVEL", this.globalLogLevel);
    const logPath = getOptionalEnvVariable("LOG_PATH", "./logs");
    const enableConsole = getOptionalEnvVariable("LOG_ENABLE_CONSOLE", "true", {
      type: "boolean"
    }) === true;
    const transports = [];
    if (enableConsole) {
      transports.push(
        new import_winston.default.transports.Console({
          format: import_winston.default.format.combine(
            import_winston.default.format.timestamp(),
            import_winston.default.format.colorize(),
            import_winston.default.format.printf(({ timestamp, level, message, ...meta }) => {
              const metaStr = Object.keys(meta).length ? (0, import_util.inspect)(meta, { colors: true, depth: 2 }) : "";
              return `${timestamp} [${category}] ${level}: ${message} ${metaStr}`.trim();
            })
          ),
          level: logLevel
        })
      );
    }
    const fileFormat = import_winston.default.format.combine(
      import_winston.default.format.timestamp(),
      import_winston.default.format.errors({ stack: true }),
      import_winston.default.format.json()
    );
    try {
      transports.push(
        new import_winston.default.transports.File({
          filename: import_path2.default.join(logPath, `${category}.log`),
          format: fileFormat,
          maxsize: 10 * 1024 * 1024,
          maxFiles: 5,
          level: logLevel
        })
      );
    } catch (e) {
      console.error(
        `[DaitanLogger] Failed to create file transport for category "${category}" in "${logPath}". Check permissions. Error: ${e.message}`
      );
    }
    const logger = import_winston.default.createLogger({
      level: logLevel,
      levels: DAITAN_LOG_LEVELS,
      transports,
      exceptionHandlers: [
        new import_winston.default.transports.File({
          filename: import_path2.default.join(logPath, "exceptions.log")
        })
      ],
      rejectionHandlers: [
        new import_winston.default.transports.File({
          filename: import_path2.default.join(logPath, "rejections.log")
        })
      ]
    });
    this.loggers.set(category, logger);
    return logger;
  }
  generateCorrelationId() {
    return import_crypto.default.randomBytes(8).toString("hex");
  }
  getLogger(category = "general") {
    if (!this.loggers.has(category)) {
      this.createLogger(category);
    }
    return this.loggers.get(category);
  }
  getAllLoggers() {
    return Array.from(this.loggers.keys());
  }
};
var rootLoggerInstance = new _DaitanRootLogger();
var getLogger = (category = "general") => rootLoggerInstance.getLogger(category);
var setGlobalLogLevel = (level) => rootLoggerInstance.setGlobalLogLevel(level);
var isLogLevelEnabled = (level, loggerLevel) => rootLoggerInstance.isLogLevelEnabled(level, loggerLevel);
var DaitanRootLogger = rootLoggerInstance;

// src/development/src/hardware.js
var import_os2 = __toESM(require("os"), 1);
var import_systeminformation = __toESM(require("systeminformation"), 1);
var import_error2 = require("@daitanjs/error");
var hardwareLogger = getLogger("daitan-hardware-info");
var isTensorFlowSupported = () => {
  const callId = `tfSupportCheck-${Date.now().toString(36)}`;
  try {
    const cpus = import_os2.default.cpus();
    if (!cpus || cpus.length === 0) {
      hardwareLogger.warn(`[${callId}] Could not retrieve CPU information to check TensorFlow.js Node support. Assuming supported.`);
      return true;
    }
    const cpuModel = cpus[0].model.toLowerCase();
    const unsupportedCPUsFragments = [
      "celeron n",
      // Catches Celeron N4000, N3350, N3450, etc.
      "celeron j",
      // Catches Celeron J4105, J1900, etc.
      "atom x5-",
      // e.g., Atom x5-Z8350
      "atom z37",
      // e.g., Atom Z3735F
      "atom d",
      // e.g., Atom D2550
      "pentium n",
      // e.g., Pentium N3540, N3710
      "pentium j"
      // e.g., Pentium J2900
      // Add other known problematic CPU model fragments here
      // Older Core 2 Duos, some very early i3/i5 might also lack AVX.
      // Consider adding checks for specific CPU flags if `systeminformation` provides them easily.
    ];
    const isUnsupported = unsupportedCPUsFragments.some((fragment) => cpuModel.includes(fragment));
    if (isUnsupported) {
      hardwareLogger.info(`[${callId}] CPU model "${cpus[0].model}" is on the list of CPUs that may lack AVX/AVX2 or have other known issues with default TensorFlow.js Node bindings. Returning false for TensorFlow support.`);
    } else {
      hardwareLogger.debug(`[${callId}] CPU model "${cpus[0].model}" not on the known unsupported list for TensorFlow.js Node. Assuming supported (AVX/AVX2 likely present).`);
    }
    return !isUnsupported;
  } catch (error) {
    hardwareLogger.warn(`[${callId}] Error checking CPU for TensorFlow.js Node support: ${error.message}. Assuming supported.`, { errorName: error.name });
    return true;
  }
};
var getCPUInfo = () => {
  const callId = `cpuInfo-${Date.now().toString(36)}`;
  hardwareLogger.debug(`[${callId}] Fetching CPU information...`);
  try {
    const cpusOs = import_os2.default.cpus();
    if (!cpusOs || cpusOs.length === 0) {
      hardwareLogger.warn(`[${callId}] os.cpus() returned no data. Basic CPU info will be unavailable.`);
      return import_systeminformation.default.cpu().then((siCpuData) => ({
        model: siCpuData.brand || "N/A (os.cpus failed)",
        cores: siCpuData.cores || 0,
        physicalCores: siCpuData.physicalCores,
        speed: siCpuData.speed || 0,
        // Speed in GHz from systeminformation
        manufacturer: siCpuData.manufacturer,
        brand: siCpuData.brand,
        vendor: siCpuData.vendor,
        family: siCpuData.family,
        modelCpu: siCpuData.model,
        stepping: siCpuData.stepping,
        revision: siCpuData.revision,
        voltage: siCpuData.voltage,
        speedMin: siCpuData.speedMin,
        speedMax: siCpuData.speedMax,
        governor: siCpuData.governor,
        cache: siCpuData.cache,
        flags: siCpuData.flags,
        virtualization: siCpuData.virtualization,
        aggregatedTimes: { user: 0, nice: 0, sys: 0, idle: 0, irq: 0 },
        // No load times from si.cpu() directly
        error: "os.cpus() failed to provide data."
      })).catch((siError) => {
        hardwareLogger.error(`[${callId}] Both os.cpus() and systeminformation.cpu() failed.`, { siError: siError.message });
        return { model: "Error Retrieving", cores: 0, speed: 0, aggregatedTimes: {}, error: `os.cpus() and si.cpu() failed: ${siError.message}` };
      });
    }
    const aggregatedTimes = cpusOs.reduce((acc, cpu) => {
      Object.keys(cpu.times).forEach((key) => {
        acc[key] = (acc[key] || 0) + cpu.times[key];
      });
      return acc;
    }, { user: 0, nice: 0, sys: 0, idle: 0, irq: 0 });
    return import_systeminformation.default.cpu().then((siCpuData) => {
      hardwareLogger.info(`[${callId}] CPU information retrieved successfully (combined os and systeminformation).`);
      return {
        model: cpusOs[0].model,
        // Prefer os.cpus model string as primary
        cores: cpusOs.length,
        // Logical cores from os.cpus
        physicalCores: siCpuData.physicalCores,
        speed: cpusOs[0].speed,
        // Speed in MHz from os.cpus
        manufacturer: siCpuData.manufacturer,
        brand: siCpuData.brand,
        // Often more descriptive than os.cpus model
        vendor: siCpuData.vendor,
        family: siCpuData.family,
        modelCpu: siCpuData.model,
        // Systeminformation's model identifier
        stepping: siCpuData.stepping,
        revision: siCpuData.revision,
        voltage: siCpuData.voltage,
        speedMin: siCpuData.speedMin,
        // Speed in GHz
        speedMax: siCpuData.speedMax,
        // Speed in GHz
        governor: siCpuData.governor,
        cache: siCpuData.cache,
        // L1d, L1i, L2, L3 cache sizes in bytes
        flags: siCpuData.flags,
        // CPU flags (e.g., "avx", "sse")
        virtualization: siCpuData.virtualization,
        aggregatedTimes
        // From os.cpus
      };
    }).catch((siError) => {
      hardwareLogger.warn(`[${callId}] systeminformation.cpu() failed: ${siError.message}. Returning os.cpus() data only.`, { errorName: siError.name });
      return {
        model: cpusOs[0].model,
        cores: cpusOs.length,
        speed: cpusOs[0].speed,
        aggregatedTimes,
        errorPartial: `systeminformation.cpu() failed: ${siError.message}`
      };
    });
  } catch (error) {
    hardwareLogger.error(`[${callId}] Error retrieving CPU info via os.cpus(): ${error.message}`, { errorName: error.name });
    return Promise.resolve({ model: "Error Retrieving", cores: 0, speed: 0, aggregatedTimes: {}, error: error.message });
  }
};
var getMemoryInfo = () => {
  const callId = `memInfo-${Date.now().toString(36)}`;
  hardwareLogger.debug(`[${callId}] Fetching memory information...`);
  try {
    const totalMemoryBytes = import_os2.default.totalmem();
    const freeMemoryBytes = import_os2.default.freemem();
    const usedMemoryBytes = totalMemoryBytes - freeMemoryBytes;
    const bytesToGB = (bytes) => parseFloat((bytes / (1024 * 1024 * 1024)).toFixed(2));
    const memoryInfo = {
      totalMemoryBytes,
      freeMemoryBytes,
      usedMemoryBytes,
      totalMemoryGB: bytesToGB(totalMemoryBytes),
      freeMemoryGB: bytesToGB(freeMemoryBytes),
      usedMemoryGB: bytesToGB(usedMemoryBytes)
    };
    hardwareLogger.info(`[${callId}] Memory information retrieved successfully.`);
    return memoryInfo;
  } catch (error) {
    hardwareLogger.error(`[${callId}] Error retrieving memory info: ${error.message}`, { errorName: error.name });
    return { totalMemoryBytes: 0, freeMemoryBytes: 0, usedMemoryBytes: 0, totalMemoryGB: 0, freeMemoryGB: 0, usedMemoryGB: 0, error: error.message };
  }
};
var getNetworkInfo = () => {
  const callId = `netInfo-${Date.now().toString(36)}`;
  hardwareLogger.debug(`[${callId}] Fetching network interface information...`);
  try {
    const networkInterfaces = import_os2.default.networkInterfaces();
    const simplifiedInterfaces = {};
    for (const name in networkInterfaces) {
      if (Object.hasOwnProperty.call(networkInterfaces, name)) {
        simplifiedInterfaces[name] = networkInterfaces[name].map((iface) => ({
          address: iface.address,
          netmask: iface.netmask,
          family: iface.family,
          mac: iface.mac,
          internal: iface.internal,
          cidr: iface.cidr
          // Available in newer Node versions
        }));
      }
    }
    hardwareLogger.info(`[${callId}] Network interface information retrieved for ${Object.keys(simplifiedInterfaces).length} interfaces.`);
    return simplifiedInterfaces;
  } catch (error) {
    hardwareLogger.error(`[${callId}] Error retrieving network info: ${error.message}`, { errorName: error.name });
    return { error: error.message };
  }
};
var getOSInfo = () => {
  const callId = `osInfo-${Date.now().toString(36)}`;
  hardwareLogger.debug(`[${callId}] Fetching OS information...`);
  try {
    const osInfo = {
      platform: import_os2.default.platform(),
      type: import_os2.default.type(),
      release: import_os2.default.release(),
      uptimeSeconds: import_os2.default.uptime(),
      architecture: import_os2.default.arch(),
      hostname: import_os2.default.hostname(),
      endianness: import_os2.default.endianness()
      // userInfo: os.userInfo(), // Potentially sensitive PII, enable with caution
      // homedir: os.homedir(),  // Potentially sensitive, enable with caution
    };
    hardwareLogger.info(`[${callId}] OS information retrieved successfully. Platform: ${osInfo.platform}, Release: ${osInfo.release}`);
    return osInfo;
  } catch (error) {
    hardwareLogger.error(`[${callId}] Error retrieving OS info: ${error.message}`, { errorName: error.name });
    return { error: error.message };
  }
};
var getLoadAverage = () => {
  const callId = `loadAvg-${Date.now().toString(36)}`;
  hardwareLogger.debug(`[${callId}] Fetching system load average...`);
  try {
    const load = import_os2.default.loadavg();
    const loadAverage = {
      "1min": load[0],
      "5min": load[1],
      "15min": load[2]
    };
    hardwareLogger.info(`[${callId}] System load average retrieved: ${load.join(", ")}`);
    return loadAverage;
  } catch (error) {
    hardwareLogger.error(`[${callId}] Error retrieving load average: ${error.message}`, { errorName: error.name });
    return { "1min": 0, "5min": 0, "15min": 0, error: error.message };
  }
};
var getGraphicsAndDisplayInfo = async () => {
  const callId = `gfxInfo-${Date.now().toString(36)}`;
  hardwareLogger.debug(`[${callId}] Fetching graphics and display information via systeminformation...`);
  try {
    const graphicsData = await import_systeminformation.default.graphics();
    hardwareLogger.info(`[${callId}] Graphics and display information retrieved. Controllers: ${graphicsData.controllers.length}, Displays: ${graphicsData.displays.length}`);
    return {
      controllers: graphicsData.controllers.map((c) => ({
        vendor: c.vendor,
        model: c.model,
        bus: c.bus,
        vramMB: c.vram,
        vramDynamic: c.vramDynamic
        // Added vramDynamic
      })),
      displays: graphicsData.displays.map((d) => ({
        vendor: d.vendor,
        model: d.model,
        main: d.main,
        builtIn: d.builtin,
        connection: d.connection,
        resolutionX: d.resolutionx,
        resolutionY: d.resolutiony,
        pixelDepth: d.pixeldepth,
        currentRefreshRate: d.currentrefreshrate,
        sizeXCm: d.sizex,
        sizeYCm: d.sizey
        // Added physical size
      }))
    };
  } catch (error) {
    hardwareLogger.error(`[${callId}] Error retrieving graphics/display info via systeminformation: ${error.message}`, { errorName: error.name });
    throw new import_error2.DaitanOperationError(`Failed to get graphics/display info using systeminformation: ${error.message}`, {}, error);
  }
};
var getUsbDevicesInfo = async () => {
  const callId = `usbInfo-${Date.now().toString(36)}`;
  hardwareLogger.debug(`[${callId}] Fetching USB devices information via systeminformation...`);
  try {
    const usbData = await import_systeminformation.default.usb();
    hardwareLogger.info(`[${callId}] USB devices information retrieved: ${usbData.length} devices found.`);
    return usbData.map((d) => ({
      id: d.id,
      bus: d.bus,
      deviceId: d.deviceId,
      name: d.name,
      type: d.type,
      vendor: d.vendor,
      manufacturer: d.manufacturer,
      maxPower: d.maxPower,
      // Added maxPower
      serialNumber: d.serial
      // Added serialNumber
    }));
  } catch (error) {
    hardwareLogger.error(`[${callId}] Error retrieving USB devices info via systeminformation: ${error.message}`, { errorName: error.name });
    throw new import_error2.DaitanOperationError(`Failed to get USB devices info using systeminformation: ${error.message}`, {}, error);
  }
};
var getAudioDevicesInfo = async () => {
  const callId = `audioInfo-${Date.now().toString(36)}`;
  hardwareLogger.debug(`[${callId}] Fetching audio devices information via systeminformation...`);
  try {
    const audioData = await import_systeminformation.default.audio();
    hardwareLogger.info(`[${callId}] Audio devices information retrieved: ${audioData.length} devices found.`);
    return audioData.map((d) => ({
      id: d.id,
      name: d.name,
      manufacturer: d.manufacturer,
      type: d.type,
      default: d.default,
      // Is it a system default device?
      status: d.status,
      // Operational status if available
      channel: d.channel,
      // e.g., 'input', 'output'
      driver: d.driver
      // Driver name
    }));
  } catch (error) {
    hardwareLogger.error(`[${callId}] Error retrieving audio devices info via systeminformation: ${error.message}`, { errorName: error.name });
    throw new import_error2.DaitanOperationError(`Failed to get audio devices info using systeminformation: ${error.message}`, {}, error);
  }
};
var getAllHardwareInfo = async () => {
  const callId = `allHwInfo-${Date.now().toString(36)}`;
  hardwareLogger.info(`[${callId}] Fetching all hardware and system information...`);
  const overallStartTime = Date.now();
  const cpuInfoPromise = getCPUInfo().catch((e) => {
    hardwareLogger.warn(`[${callId}] Failed to get CPU info for getAllHardwareInfo: ${e.message}. Using defaults.`);
    return { model: "Error", cores: 0, speed: 0, aggregatedTimes: {}, error: e.message };
  });
  const [
    cpuData,
    // Result of the now async getCPUInfo
    graphicsInfo,
    usbInfo,
    audioInfo
    // Other systeminformation calls can be added here
    // systemData, biosData, baseboardData, diskLayoutData, batteryData
  ] = await Promise.allSettled([
    // Use allSettled to ensure all promises complete
    cpuInfoPromise,
    getGraphicsAndDisplayInfo(),
    getUsbDevicesInfo(),
    getAudioDevicesInfo()
    // Example: si.system(), si.bios(), si.baseboard(), si.diskLayout(), si.battery()
  ]);
  const processPromiseSettledResult = (settledResult, fieldName, defaultValue = { error: "Failed to fetch" }) => {
    if (settledResult.status === "fulfilled") {
      return settledResult.value;
    } else {
      hardwareLogger.warn(`[${callId}] Failed to get ${fieldName} for getAllHardwareInfo: ${settledResult.reason.message}`);
      return { ...defaultValue, error: settledResult.reason.message };
    }
  };
  const allInfo = {
    isTensorFlowCpuSupported: isTensorFlowSupported(),
    // This is synchronous
    cpu: processPromiseSettledResult(cpuData, "CPU Info", { model: "Error", cores: 0, speed: 0, aggregatedTimes: {} }),
    memory: getMemoryInfo(),
    // Synchronous
    os: getOSInfo(),
    // Synchronous
    networkInterfaces: getNetworkInfo(),
    // Synchronous
    loadAverage: getLoadAverage(),
    // Synchronous
    graphicsAndDisplays: processPromiseSettledResult(graphicsInfo, "Graphics/Displays", { controllers: [], displays: [] }),
    usbDevices: processPromiseSettledResult(usbInfo, "USB Devices", []),
    audioDevices: processPromiseSettledResult(audioInfo, "Audio Devices", [])
    // system: processPromiseSettledResult(systemData, "System (si.system)", {}),
    // bios: processPromiseSettledResult(biosData, "BIOS (si.bios)", {}),
    // baseboard: processPromiseSettledResult(baseboardData, "Baseboard (si.baseboard)", {}),
    // diskLayout: processPromiseSettledResult(diskLayoutData, "Disk Layout (si.diskLayout)", []),
    // battery: processPromiseSettledResult(batteryData, "Battery (si.battery)", {}),
  };
  hardwareLogger.info(`[${callId}] All hardware information aggregated. Duration: ${Date.now() - overallStartTime}ms`);
  return allInfo;
};

// src/development/src/tools.js
var devToolsLogger = getLogger("daitan-dev-tools");
var devSimpleLog = (content, condition = true, consoleMethod = "log", logPrefix = "[DaitanDevLog]") => {
  if (condition) {
    const validMethods = [
      "log",
      "warn",
      "error",
      "info",
      "debug",
      "table",
      "dir"
    ];
    const methodToUse = validMethods.includes(consoleMethod) ? consoleMethod : "log";
    if (typeof console[methodToUse] === "function") {
      console[methodToUse](logPrefix, content);
    } else {
      console.log(logPrefix, content);
    }
  }
};
var devMultitestExample = () => {
  devToolsLogger.info(
    "devMultitestExample (deprecated placeholder) called. Returning 4."
  );
  return 4;
};
devToolsLogger.debug("DaitanJS Development Tools module loaded.");

// src/development/src/googleAuth.js
var import_googleapis = require("googleapis");
var import_error3 = require("@daitanjs/error");
var googleAuthLogger = getLogger("daitan-dev-google-auth");
var oauth2ClientInstance = null;
function initializeOAuth2Client() {
  if (oauth2ClientInstance) {
    googleAuthLogger.debug("Returning existing Google OAuth2 client instance.");
    return oauth2ClientInstance;
  }
  googleAuthLogger.info(
    "Initializing Google OAuth2 client for @daitanjs/development..."
  );
  try {
    const clientId = getRequiredEnvVariable(
      "GOOGLE_CLIENT_ID",
      "string",
      "Google OAuth Client ID"
    );
    const clientSecret = getRequiredEnvVariable(
      "GOOGLE_CLIENT_SECRET",
      "string",
      "Google OAuth Client Secret"
    );
    const redirectUri = getRequiredEnvVariable(
      "GOOGLE_REDIRECT_URI",
      "string",
      "Google OAuth Redirect URI"
    );
    oauth2ClientInstance = new import_googleapis.google.auth.OAuth2(
      clientId,
      clientSecret,
      redirectUri
    );
    googleAuthLogger.info("Google OAuth2 client initialized successfully.");
    return oauth2ClientInstance;
  } catch (error) {
    googleAuthLogger.error("Failed to initialize Google OAuth2 client.", {
      errorMessage: error.message,
      errorName: error.name
    });
    if (error instanceof import_error3.DaitanConfigurationError) throw error;
    throw new import_error3.DaitanConfigurationError(
      `Google OAuth2 client setup failed: ${error.message}`,
      {},
      error
    );
  }
}
var getGoogleAuthClient = () => {
  if (!oauth2ClientInstance) {
    initializeOAuth2Client();
  }
  return oauth2ClientInstance;
};
var googleAuth_default = getGoogleAuthClient;

// src/development/src/index.js
var devIndexLogger = getLogger("daitan-development-index");
devIndexLogger.debug("Exporting DaitanJS Development utilities...");
devIndexLogger.info("DaitanJS Development utilities module exports ready.");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  DAITAN_LOG_LEVELS,
  DaitanRootLogger,
  checkEnv,
  daitanDevGoogleOAuthClient,
  devMultitestExample,
  devSimpleLog,
  getAllHardwareInfo,
  getAudioDevicesInfo,
  getCPUInfo,
  getEnvVariable,
  getGoogleAuthClient,
  getGraphicsAndDisplayInfo,
  getLoadAverage,
  getLogger,
  getMemoryInfo,
  getNetworkInfo,
  getOSInfo,
  getOptionalEnvVariable,
  getRequiredEnvVariable,
  getUsbDevicesInfo,
  isLogLevelEnabled,
  isTensorFlowSupported,
  loadEnvironmentFiles,
  setGlobalLogLevel
});
//# sourceMappingURL=index.cjs.map
